From: tip-bot for Ingo Molnar <tipbot@zytor.com>
To: linux-tip-commits@vger.kernel.org
Cc: linux-kernel@vger.kernel.org, hpa@zytor.com, dvlasenk@redhat.com,
mingo@kernel.org, bp@alien8.de, peterz@infradead.org,
tglx@linutronix.de, luto@amacapital.net, brgerst@gmail.com,
akpm@linux-foundation.org, torvalds@linux-foundation.org
Subject: [tip:x86/asm] x86/asm/entry: Fix remaining use of SYSCALL_VECTOR
Date: Sun, 10 May 2015 23:41:38 -0700 [thread overview]
Message-ID: <tip-f435e68fe74d41a34124e49c07ff9f9cd7954e35@git.kernel.org> (raw)
In-Reply-To: <1431185813-15413-4-git-send-email-brgerst@gmail.com>
Commit-ID: f435e68fe74d41a34124e49c07ff9f9cd7954e35
Gitweb: http://git.kernel.org/tip/f435e68fe74d41a34124e49c07ff9f9cd7954e35
Author: Ingo Molnar <mingo@kernel.org>
AuthorDate: Mon, 11 May 2015 07:17:04 +0200
Committer: Ingo Molnar <mingo@kernel.org>
CommitDate: Mon, 11 May 2015 07:17:04 +0200
x86/asm/entry: Fix remaining use of SYSCALL_VECTOR
Commit:
51bb92843edc ("x86/asm/entry: Remove SYSCALL_VECTOR")
Converted most uses of SYSCALL_VECTOR to IA32_SYSCALL_VECTOR, but
forgot about lguest.
Cc: Brian Gerst <brgerst@gmail.com>
Cc: Andrew Morton <akpm@linux-foundation.org>
Cc: Andy Lutomirski <luto@amacapital.net>
Cc: Borislav Petkov <bp@alien8.de>
Cc: Denys Vlasenko <dvlasenk@redhat.com>
Cc: H. Peter Anvin <hpa@zytor.com>
Cc: Linus Torvalds <torvalds@linux-foundation.org>
Cc: Peter Zijlstra <peterz@infradead.org>
Cc: Thomas Gleixner <tglx@linutronix.de>
Link: http://lkml.kernel.org/r/1431185813-15413-4-git-send-email-brgerst@gmail.com
Signed-off-by: Ingo Molnar <mingo@kernel.org>
---
drivers/lguest/interrupts_and_traps.c | 10 +++++-----
1 file changed, 5 insertions(+), 5 deletions(-)
diff --git a/drivers/lguest/interrupts_and_traps.c b/drivers/lguest/interrupts_and_traps.c
index 5e7559b..eb934b0 100644
--- a/drivers/lguest/interrupts_and_traps.c
+++ b/drivers/lguest/interrupts_and_traps.c
@@ -20,7 +20,7 @@
#include "lg.h"
/* Allow Guests to use a non-128 (ie. non-Linux) syscall trap. */
-static unsigned int syscall_vector = SYSCALL_VECTOR;
+static unsigned int syscall_vector = IA32_SYSCALL_VECTOR;
module_param(syscall_vector, uint, 0444);
/* The address of the interrupt handler is split into two bits: */
@@ -333,8 +333,8 @@ void set_interrupt(struct lg_cpu *cpu, unsigned int irq)
*/
static bool could_be_syscall(unsigned int num)
{
- /* Normal Linux SYSCALL_VECTOR or reserved vector? */
- return num == SYSCALL_VECTOR || num == syscall_vector;
+ /* Normal Linux IA32_SYSCALL_VECTOR or reserved vector? */
+ return num == IA32_SYSCALL_VECTOR || num == syscall_vector;
}
/* The syscall vector it wants must be unused by Host. */
@@ -351,7 +351,7 @@ bool check_syscall_vector(struct lguest *lg)
int init_interrupts(void)
{
/* If they want some strange system call vector, reserve it now */
- if (syscall_vector != SYSCALL_VECTOR) {
+ if (syscall_vector != IA32_SYSCALL_VECTOR) {
if (test_bit(syscall_vector, used_vectors) ||
vector_used_by_percpu_irq(syscall_vector)) {
printk(KERN_ERR "lg: couldn't reserve syscall %u\n",
@@ -366,7 +366,7 @@ int init_interrupts(void)
void free_interrupts(void)
{
- if (syscall_vector != SYSCALL_VECTOR)
+ if (syscall_vector != IA32_SYSCALL_VECTOR)
clear_bit(syscall_vector, used_vectors);
}
next prev parent reply other threads:[~2015-05-11 6:42 UTC|newest]
Thread overview: 10+ messages / expand[flat|nested] mbox.gz Atom feed top
2015-05-09 15:36 [PATCH 0/4] x86: IRQ cleanups Brian Gerst
2015-05-09 15:36 ` [PATCH 1/4] x86: Merge irq_regs & irq_stat Brian Gerst
2015-05-11 6:40 ` [tip:x86/asm] x86/irq: " tip-bot for Brian Gerst
2015-05-09 15:36 ` [PATCH 2/4] x86: Remove unused invalidate_interrupt prototypes Brian Gerst
2015-05-11 6:40 ` [tip:x86/asm] x86/asm/entry/irq: " tip-bot for Brian Gerst
2015-05-09 15:36 ` [PATCH 3/4] x86: Remove SYSCALL_VECTOR Brian Gerst
2015-05-11 6:40 ` [tip:x86/asm] x86/asm/entry: " tip-bot for Brian Gerst
2015-05-11 6:41 ` tip-bot for Ingo Molnar [this message]
2015-05-09 15:36 ` [PATCH 4/4] x86: Clean up IRQn_VECTOR macros Brian Gerst
2015-05-11 6:41 ` [tip:x86/asm] x86/asm/entry/irq: " tip-bot for Brian Gerst
Reply instructions:
You may reply publicly to this message via plain-text email
using any one of the following methods:
* Save the following mbox file, import it into your mail client,
and reply-to-all from there: mbox
Avoid top-posting and favor interleaved quoting:
https://en.wikipedia.org/wiki/Posting_style#Interleaved_style
* Reply using the --to, --cc, and --in-reply-to
switches of git-send-email(1):
git send-email \
--in-reply-to=tip-f435e68fe74d41a34124e49c07ff9f9cd7954e35@git.kernel.org \
--to=tipbot@zytor.com \
--cc=akpm@linux-foundation.org \
--cc=bp@alien8.de \
--cc=brgerst@gmail.com \
--cc=dvlasenk@redhat.com \
--cc=hpa@zytor.com \
--cc=linux-kernel@vger.kernel.org \
--cc=linux-tip-commits@vger.kernel.org \
--cc=luto@amacapital.net \
--cc=mingo@kernel.org \
--cc=peterz@infradead.org \
--cc=tglx@linutronix.de \
--cc=torvalds@linux-foundation.org \
/path/to/YOUR_REPLY
https://kernel.org/pub/software/scm/git/docs/git-send-email.html
* If your mail client supports setting the In-Reply-To header
via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line
before the message body.
This is an external index of several public inboxes,
see mirroring instructions on how to clone and mirror
all data and code used by this external index.